@@ -949,6 +949,7 @@ SEXP do_merge_xts (SEXP x, SEXP y,
   if(LOGICAL(retclass)[0])
     setAttrib(result, R_ClassSymbol, getAttrib(x, R_ClassSymbol));
   setAttrib(result, xts_IndexClassSymbol, getAttrib(x, xts_IndexClassSymbol));
+  setAttrib(result, xts_IndexTZSymbol, getAttrib(x, xts_IndexTZSymbol));
   setAttrib(result, xts_IndexFormatSymbol, getAttrib(x, xts_IndexFormatSymbol));
   setAttrib(result, xts_ClassSymbol, getAttrib(x, xts_ClassSymbol));
   copy_xtsAttributes(x, result);
@@ -1178,6 +1179,7 @@ SEXP mergeXts (SEXP args) // mergeXts {{{
     setAttrib(result, R_DimNamesSymbol, dimnames);
 
     SET_xtsIndex(result, GET_xtsIndex(_INDEX));
+    SET_xtsIndexTZ(result, GET_xtsIndexTZ(_INDEX));
     copy_xtsCoreAttributes(_INDEX, result);
     copy_xtsAttributes(_INDEX, result);
 
